==> org-lsst-ccs-subsystem-fcs-main-5.1.1-sources.jar: org/lsst/ccs/subsystems/fcs/simulation/SimuCarouselStandalonePlutoGateway.java <==

package org.lsst.ccs.subsystems.fcs.simulation;

import org.lsst.ccs.command.annotations.Command;
import org.lsst.ccs.commons.annotations.LookupField;
import org.lsst.ccs.commons.annotations.LookupField.Strategy;
import org.lsst.ccs.subsystems.fcs.DigitalSensor;

/**
 * Used only for Simulation to simulate a gateway where we read the fake autochanger sensor.
 * In carousel-standalone subsystem, there is an electric switch connected to a numeric sensor.
 * This sensor : autochangerHoldingFilterSensor simulates that the autochnager is holding a filter or not.
 * Therefore we can do mechanical tests of unlocking clamps.
 *
 * @author virieux
 */
public class SimuCarouselStandalonePlutoGateway extends SimuPlutoGateway {
    
    @LookupField(strategy=Strategy.BYNAME)
    private DigitalSensor autochangerHoldingFilterSensor0;
    
    @LookupField(strategy=Strategy.BYNAME)
    private DigitalSensor autochangerHoldingFilterSensor1;
    
    /**
     * Build a new SimuCarouselStandalonePlutoGateway
     * @param nodeID
     * @param serialNB 
     */
    public SimuCarouselStandalonePlutoGateway(int nodeID, String serialNB) {
        super(nodeID, serialNB);
    }

    @Override
    public void init() {
        this.initialized = true;
    }
    
    /**
     * For the simulation software, set autochangerHoldingFilterSensor value to 1.
     */
    @Command(type = Command.CommandType.QUERY, level = Command.ENGINEERING1)
    public void simulateAutochangerIsHoldingFilter() {
        replaceValues(autochangerHoldingFilterSensor0, true);
        replaceValues(autochangerHoldingFilterSensor1, false);
    }

    /**
     * For the simulation software, set autochangerHoldingFilterSensor value to 0.
     */
    @Command(type = Command.CommandType.QUERY, level = Command.ENGINEERING1)
    public void simulateAutochangerIsNotHoldingFilter() {
        replaceValues(autochangerHoldingFilterSensor0, false);
        replaceValues(autochangerHoldingFilterSensor1, true);
    }
}

==> org-lsst-ccs-subsystem-fcs-main-5.1.13-sources.jar: org/lsst/ccs/subsystems/fcs/simulation/SimuCarouselStandalonePlutoGateway.java <==

package org.lsst.ccs.subsystems.fcs.simulation;

import org.lsst.ccs.command.annotations.Command;
import org.lsst.ccs.commons.annotations.LookupField;
import org.lsst.ccs.commons.annotations.LookupField.Strategy;
import org.lsst.ccs.subsystems.fcs.DigitalSensor;

/**
 * Used only for Simulation to simulate a gateway where we read the fake autochanger sensor.
 * In carousel-standalone subsystem, there is an electric switch connected to a numeric sensor.
 * This sensor : autochangerHoldingFilterSensor simulates that the autochnager is holding a filter or not.
 * Therefore we can do mechanical tests of unlocking clamps.
 *
 * @author virieux
 */
public class SimuCarouselStandalonePlutoGateway extends SimuPlutoGateway {
    
    @LookupField(strategy=Strategy.BYNAME)
    private DigitalSensor autochangerHoldingFilterSensor0;
    
    @LookupField(strategy=Strategy.BYNAME)
    private DigitalSensor autochangerHoldingFilterSensor1;
    
    /**
     * Build a new SimuCarouselStandalonePlutoGateway
     * @param nodeID
     * @param serialNB 
     */
    public SimuCarouselStandalonePlutoGateway(int nodeID, String serialNB) {
        super(nodeID, serialNB);
    }

    @Override
    public void init() {
        this.initialized = true;
    }
    
    /**
     * For the simulation software, set autochangerHoldingFilterSensor value to 1.
     */
    @Command(type = Command.CommandType.QUERY, level = Command.ENGINEERING1)
    public void simulateAutochangerIsHoldingFilter() {
        replaceSensorValue(autochangerHoldingFilterSensor0, true);
        replaceSensorValue(autochangerHoldingFilterSensor1, false);
    }

    /**
     * For the simulation software, set autochangerHoldingFilterSensor value to 0.
     */
    @Command(type = Command.CommandType.QUERY, level = Command.ENGINEERING1)
    public void simulateAutochangerIsNotHoldingFilter() {
        replaceSensorValue(autochangerHoldingFilterSensor0, false);
        replaceSensorValue(autochangerHoldingFilterSensor1, true);
    }
}
